@@ -316,7 +316,10 @@ class Scan:
         iterator = _get_iterator(unp.nominal_values(self.q), progress)
         to_remove = []
         for i in iterator:
-            im = image.Image(self.data["file"][i], self.data, self.metadata, pixel_maximum=self.pixel_max, hot_pixel_threshold=self.hot_pixel_threshold)
+            if self.data['roi1_maxval'] > self.pixel_max:
+                to_remove.append(i)
+                continue
+            im = image.Image(self.data["file"][i], self.data, self.metadata, hot_pixel_threshold=self.hot_pixel_threshold)
             if im.skip:
                 to_remove.append(i)
                 continue
